#! @PERL5@
#
# Copyright (C) 1996 Ken MacLeod
# See the file COPYING for distribution terms.
#

$package = "gdo";
$version = "@VERSION@";

use ExtUtils::Manifest;
require 'timelocal.pl';
use POSIX qw{strftime};

$prog = $0;

$prog =~ s|.*/||;

#
# These files will be skipped by `manicopy' and `fullcheck'
#
open (MANIFEST_SKIP, ">MANIFEST.SKIP")
    or die "$prog: could not open \`MANIFEST.SKIP' for writing: $!\n";
print MANIFEST_SKIP <<'EOF';
\bRCS\b
^MANIFEST\.
^Makefile$
^test/Makefile$
^perl/GDO.pm$
^make-dist$
^\.release$
~$
EOF

close (MANIFEST_SKIP);

#
# Get a release number or snapshot into $release
#
if (open (RELEASE, ".release")) {
    # this is an official release

    $release = <RELEASE>;
    substr ($release, -1) = ""
	if (substr ($release, -1) eq "\n");
    die "$prog: \`.release' does not match version\n"
	if ($release ne $version);
    die "$prog: tar file for package \`$package-$version' already exists\n"
	if (-f "../$package-$version.tar.gz"
	    || -d "../$package-$version");
    close (RELEASE);
} else {
    # this is a development snapshot
    ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst) =
	localtime(time);

    $dev_release .= "d" . strftime ("%y%m%d", $sec, $min, $hour, $mday, $mon, $year);
    if (-f "../$package-$version$dev_release.tar.gz"
	|| -d "../$package-$version$dev_release") {
	$dev_suffix = "a";
	while (-f "../$package-$version$dev_release$dev_suffix.tar.gz"
	       || -d "../$package-$version$dev_release$dev_suffix") {
	    $dev_suffix ++;
	}
	$dev_release .= $dev_suffix;
    }
    $version .= $dev_release;
}

$package_version = "$package-$version";

($missfile, $missentry) = ExtUtils::Manifest::fullcheck;
die "$prog: release does not check against manifest\n"
    if ($#{$missfile} != -1 || $#{$missentry} != -1);

ExtUtils::Manifest::manicopy(ExtUtils::Manifest::maniread,
			     "../$package_version");

unlink ("MANIFEST.SKIP");

#
# Create a ``version'' specific RPM `spec' file
#
open (GDO_SPEC, "gdo.spec")
    or die "$prog: can't open \`gdo.spec' for reading: $!\n";
open (GDO_VER_SPEC, ">../$package_version/$package_version.spec")
    or die "$prog: can't open \`../$package_version/$package_version.spec' for writing: $!\n";
while (<GDO_SPEC>) {
    s/\@VERSION\@/$version/;
    print GDO_VER_SPEC;
}
close (GDO_VER_SPEC);
close (GDO_SPEC);

#
# Create a ``version'' specific RPM `spec' file
#
foreach $fn ('configure.in', 'configure') {
    open (GDO_FILE, $fn)
	or die "$prog: can't open \`$fn' for reading: $!\n";
    open (GDO_VER_FILE, ">../$package_version/$fn")
	or die "$prog: can't open \`../$package_version/$fn' for writing: $!\n";
    while (<GDO_FILE>) {
	s/^version='[^']+'$/version='$version'/;
	print GDO_VER_FILE;
    }
    close (GDO_VER_FILE);
    close (GDO_FILE);
}

#
# Add the ``version'' specific RPM `spec' file to the MANIFEST after
# the templace RPM `spec' file
#
open (GDO_MANIFEST, "MANIFEST")
    or die "$prog: can't open \`MANIFEST' for reading: $!\n";
open (GDO_VER_MANIFEST, ">../$package_version/MANIFEST")
    or die "$prog: can't open \`../$package_version/MANIFEST' for writing: $!\n";
while (<GDO_MANIFEST>) {
    print GDO_VER_MANIFEST;
    if (/^gdo.spec\s/) {
	print GDO_VER_MANIFEST "$package_version.spec             RPM `spec' file for $package $version";
    }
}
close (GDO_VER_MANIFEST);
close (GDO_MANIFEST);

chdir "..";

system 'tar', 'czvf', "$package_version.tar.gz", "$package_version";

system 'rm', '-r', "$package_version";
