#! /bin/sh
#
# NAME
#     gdo-test -- run `gdo' across many documents
#

if test "0$GDOPATH" = "0"; then
  echo "env GDOPATH must be set to GDO source dir"
  exit 1
fi

SROFF=$GDOPATH/sroff;
DOCDIR=/usr/doc
TESTDIR=test
MKDIRHIER="mkdir -p"

if [ "0$1" != "0" ]; then
  OUTPUTTYPES="$1"
else
  OUTPUTTYPES="Ascii,HTML"
fi

test -d $TESTDIR || $MKDIRHIER $TESTDIR

# TEI Lite
if [ -f $DOCDIR/teilite-1.6-1/teiu5.tei ]; then
  DOCS="$DOCS $DOCDIR/teilite-1.6-1/teiu5.tei"
fi

# DocBook
if [ -f $DOCDIR/SGMLSpm-1.03ii-1/sgmlspm.sgml ]; then
  DOCS="$DOCS $DOCDIR/SGMLSpm-1.03ii-1/sgmlspm.sgml"
  DOCS="$DOCS $DOCDIR/SGMLSpm-1.03ii-1/sgmlspl.sgml"
fi

# Snafu
if [ -f $DOCDIR/html-spec-19950922-1/html-spec.sgm ]; then
  DOCS="$DOCS $DOCDIR/html-spec-19950922-1/html-spec.sgm"
fi

# DocBook 2.3
if [ -f $DOCDIR/docbk-23-1/maint11.sgm ]; then
  DOCS="$DOCS $DOCDIR/docbk-23-1/maint11.sgm"
fi

# DocBook 2.2
if [ -f $DOCDIR/docbook-2.2.1-1/ch03.sgm ]; then
  DOCS="$DOCS $DOCDIR/docbook-2.2.1-1/ch03.sgm"
  DOCS="$DOCS $DOCDIR/docbook-2.2.1-1/fullguide.sgm"
fi

# Snafu
if [ -f $DOCDIR/gf-0.43-1/snafu.sgml ]; then
  DOCS="$DOCS $DOCDIR/gf-0.43-1/snafu.sgml"
  DOCS="$DOCS $DOCDIR/gf-0.43-1/gf.sgml"
fi

# Qwertz
if [ -f sgml2latex-format-1.3/doc/qwertz.sgml ]; then
  DOCS="$DOCS sgml2latex-format-1.3/doc/qwertz.sgml"
  DOCS="$DOCS sgml2latex-format-1.3/doc/manual.sgml"
  DOCS="$DOCS sgml2latex-format-1.3/doc/biblio.sgml"
  DOCS="$DOCS sgml2latex-format-1.3/doc/bibintro.sgml"
  DOCS="$DOCS sgml2latex-format-1.3/man/man1/fax.1.sgml"
  DOCS="$DOCS sgml2latex-format-1.3/man/man1/format.1.sgml"
  DOCS="$DOCS sgml2latex-format-1.3/man/man1/qtex.1.sgml"
  DOCS="$DOCS sgml2latex-format-1.3/man/man1/qroff.1.sgml"
  DOCS="$DOCS sgml2latex-format-1.3/man/man1/extract.1.sgml"
  DOCS="$DOCS sgml2latex-format-1.3/man/man1/biblio.1.sgml"
  DOCS="$DOCS sgml2latex-format-1.3/test/test.sgml"
  DOCS="$DOCS sgml2latex-format-1.3/test/lit.sgml"
  DOCS="$DOCS sgml2latex-format-1.3/test/test.max.sgml"
fi

# Linuxdoc
if [ -f $DOCDIR/linuxdoc-sgml-1.4/guide.sgml ]; then
  DOCS="$DOCS $DOCDIR/linuxdoc-sgml-1.4/guide.sgml"
  DOCS="$DOCS $DOCDIR/linuxdoc-sgml-1.4/example.sgml"
fi

for ii in $DOCS; do
  DIRNAME="$TESTDIR/`echo $ii | sed -e 's|/.*||'`"
  DOCNAME="`basename $ii`"
  BASENAME="`echo $DOCNAME | sed -e 's|\.sgm$||' -e 's|\.sgml||'`"
  test -d $DIRNAME || $MKDIRHIER $DIRNAME
  echo "---- $SROFF -O$OUTPUTTYPES -o $DIRNAME/$BASENAME $ii ----"
  $SROFF -O$OUTPUTTYPES -o $DIRNAME/$BASENAME $ii
done
